#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ULP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ULP_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/ulp.hpp>

#endif
